HGraph Concepts
===============

HGraph embodies a number of interesting and potentially unique ideas. In it's simplest form
HGraph is an advanced event processor. This section will describe the key concepts and patterns
that make up the framework.

.. toctree::
    run_loop_concept
    node_based_computation
    typing_system
    time_series_types
    dynamic_graphs
    tsd_map_node
    services



